==> org-lsst-sal-camera-2.5.0-sources.jar: org/lsst/sal/camera/event/Focal_plane_Segment_LimitsConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import java.util.Arrays;
import org.lsst.sal.camera.CameraEvent;

public class Focal_plane_Segment_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double[] i_warnHi;

  private final double[] i_warnLo;

  private final double[] i_limitHi;

  private final double[] i_limitLo;

  private final String location;

  public Focal_plane_Segment_LimitsConfigurationEvent(int priority, String version,
      double[] i_warnHi, double[] i_warnLo, double[] i_limitHi, double[] i_limitLo,
      String location) {
    super (priority);
    this.version = version;
    this.i_warnHi = i_warnHi;
    this.i_warnLo = i_warnLo;
    this.i_limitHi = i_limitHi;
    this.i_limitLo = i_limitLo;
    this.location = location;
  }

  public String getVersion() {
    return version;
  }

  public double[] getI_warnHi() {
    return i_warnHi;
  }

  public double[] getI_warnLo() {
    return i_warnLo;
  }

  public double[] getI_limitHi() {
    return i_limitHi;
  }

  public double[] getI_limitLo() {
    return i_limitLo;
  }

  public String getLocation() {
    return location;
  }

  @Override
  public String toString() {
    return "Focal_plane_Segment_LimitsConfigurationEvent{" + "version=" + version +
        ", i_warnHi=" + Arrays.toString(i_warnHi) +", i_warnLo=" + Arrays.toString(i_warnLo) +
        ", i_limitHi=" + Arrays.toString(i_limitHi) +", i_limitLo=" + Arrays.toString(i_limitLo) +
        ", location=" + location +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private double[] i_warnHi;

    private double[] i_warnLo;

    private double[] i_limitHi;

    private double[] i_limitLo;

    private String location;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder i_warnHi(double[] i_warnHi) {
      this.i_warnHi = i_warnHi;
      return this;
    }

    public Builder i_warnLo(double[] i_warnLo) {
      this.i_warnLo = i_warnLo;
      return this;
    }

    public Builder i_limitHi(double[] i_limitHi) {
      this.i_limitHi = i_limitHi;
      return this;
    }

    public Builder i_limitLo(double[] i_limitLo) {
      this.i_limitLo = i_limitLo;
      return this;
    }

    public Builder location(String location) {
      this.location = location;
      return this;
    }

    public Focal_plane_Segment_LimitsConfigurationEvent build() {
      return new Focal_plane_Segment_LimitsConfigurationEvent(priority, version, i_warnHi, i_warnLo, i_limitHi, i_limitLo, location);
    }
  }
}

==> org-lsst-sal-camera-3.0.2-sources.jar: org/lsst/sal/camera/event/Focal_plane_Segment_LimitsConfigurationEvent.java <==
package org.lsst.sal.camera.event;

import java.util.Arrays;
import org.lsst.sal.camera.CameraEvent;

public class Focal_plane_Segment_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double[] i_warnHi;

  private final double[] i_warnLo;

  private final double[] i_limitHi;

  private final double[] i_limitLo;

  private final String location;

  public Focal_plane_Segment_LimitsConfigurationEvent(String version, double[] i_warnHi,
      double[] i_warnLo, double[] i_limitHi, double[] i_limitLo, String location) {
    this.version = version;
    this.i_warnHi = i_warnHi;
    this.i_warnLo = i_warnLo;
    this.i_limitHi = i_limitHi;
    this.i_limitLo = i_limitLo;
    this.location = location;
  }

  public String getVersion() {
    return version;
  }

  public double[] getI_warnHi() {
    return i_warnHi;
  }

  public double[] getI_warnLo() {
    return i_warnLo;
  }

  public double[] getI_limitHi() {
    return i_limitHi;
  }

  public double[] getI_limitLo() {
    return i_limitLo;
  }

  public String getLocation() {
    return location;
  }

  @Override
  public String toString() {
    return "Focal_plane_Segment_LimitsConfigurationEvent{" + "version=" + version +
        ", i_warnHi=" + Arrays.toString(i_warnHi) +", i_warnLo=" + Arrays.toString(i_warnLo) +
        ", i_limitHi=" + Arrays.toString(i_limitHi) +", i_limitLo=" + Arrays.toString(i_limitLo) +
        ", location=" + location +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private double[] i_warnHi;

    private double[] i_warnLo;

    private double[] i_limitHi;

    private double[] i_limitLo;

    private String location;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder i_warnHi(double[] i_warnHi) {
      this.i_warnHi = i_warnHi;
      return this;
    }

    public Builder i_warnLo(double[] i_warnLo) {
      this.i_warnLo = i_warnLo;
      return this;
    }

    public Builder i_limitHi(double[] i_limitHi) {
      this.i_limitHi = i_limitHi;
      return this;
    }

    public Builder i_limitLo(double[] i_limitLo) {
      this.i_limitLo = i_limitLo;
      return this;
    }

    public Builder location(String location) {
      this.location = location;
      return this;
    }

    public Focal_plane_Segment_LimitsConfigurationEvent build() {
      return new Focal_plane_Segment_LimitsConfigurationEvent(version, i_warnHi, i_warnLo, i_limitHi, i_limitLo, location);
    }
  }
}
